@@ -10,7 +10,7 @@ use Mojo::SQLite::Transaction;
 use Mojo::Util qw(deprecated monkey_patch);
 use Scalar::Util 'weaken';
 
-our $VERSION = '2.000';
+our $VERSION = '2.001';
 
 our @CARP_NOT = qw(Mojo::SQLite::Migrations);
 
@@ -24,7 +24,7 @@ has notification_poll_interval => sub {
 has results_class              => 'Mojo::SQLite::Results';
 
 for my $name (qw(delete insert select update)) {
-  monkey_patch __PACKAGE__, lc $name, sub {
+  monkey_patch __PACKAGE__, $name, sub {
     my ($self, @cb) = (shift, ref $_[-1] eq 'CODE' ? pop : ());
     return $self->query($self->sqlite->abstract->$name(@_), @cb);
   };
@@ -393,6 +393,18 @@ a blocking manner.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+Use all the same argument variations you would pass to the C<delete> method of
+L<SQL::Abstract>.
+
+  # "delete from some_table"
+  $db->delete('some_table');
+
+  # "delete from some_table where foo = 'bar'"
+  $db->delete('some_table', {foo => 'bar'});
+
+  # "delete from some_table where foo like '%test%'"
+  $db->delete('some_table', {foo => {-like => '%test%'}});
+
 =head2 disconnect
 
   $db->disconnect;
@@ -414,6 +426,12 @@ a blocking manner.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+Use all the same argument variations you would pass to the C<insert> method of
+L<SQL::Abstract>.
+
+  # "insert into some_table (foo, baz) values ('bar', 'yada')"
+  $db->insert('some_table', {foo => 'bar', baz => 'yada'});
+
 =head2 is_listening
 
 This method is L<DEPRECATED|Mojo::SQLite::PubSub/"DESCRIPTION">.
@@ -440,11 +458,12 @@ Check database connection.
   my $results = $db->query('select ? as foo', {json => {bar => 'baz'}});
 
 Execute a blocking L<SQL|http://www.postgresql.org/docs/current/static/sql.html>
-statement and return a results object based on L</"results_class"> with the
-query results. The L<DBD::SQLite> statement handle will be automatically reused
-when it is not active anymore, to increase the performance of future queries.
-You can also append a callback for API compatibility with L<Mojo::Pg>; the
-query is still executed in a blocking manner.
+statement and return a results object based on L</"results_class"> (which is
+usually L<Mojo::SQLite::Results>) with the query results. The L<DBD::SQLite>
+statement handle will be automatically reused when it is not active anymore, to
+increase the performance of future queries. You can also append a callback for
+API compatibility with L<Mojo::Pg>; the query is still executed in a blocking
+manner.
 
   $db->query('insert into foo values (?, ?, ?)' => @values => sub {
     my ($db, $err, $results) = @_;
@@ -480,6 +499,24 @@ a blocking manner.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+Use all the same argument variations you would pass to the C<select> method of
+L<SQL::Abstract>.
+
+  # "select * from some_table"
+  $db->select('some_table');
+
+  # "select id, foo from some_table"
+  $db->select('some_table', ['id', 'foo']);
+
+  # "select * from some_table where foo = 'bar'"
+  $db->select('some_table', undef, {foo => 'bar'});
+
+  # "select * from some_table where foo = 'bar' order by id desc"
+  $db->select('some_table', undef, {foo => 'bar'}, {-desc => 'id'});
+
+  # "select * from some_table where foo like '%test%'"
+  $db->select('some_table', undef, {foo => {-like => '%test%'}});
+
 =head2 tables
 
   my $tables = $db->tables;
@@ -512,6 +549,15 @@ a blocking manner.
   });
   Mojo::IOLoop->start unless Mojo::IOLoop->is_running;
 
+Use all the same argument variations you would pass to the C<update> method of
+L<SQL::Abstract>.
+
+  # "update some_table set foo = 'bar' where id = 23"
+  $db->update('some_table', {foo => 'bar'}, {id => 23});
+
+  # "update some_table set foo = 'bar' where foo like '%test%'"
+  $db->update('some_table', {foo => 'bar'}, {foo => {-like => '%test%'}});
+
 =head1 BUGS
 
 Report any issues on the public bugtracker.
